@@ -2,7 +2,7 @@ package Mail::DMARC::Report::Receive;
 use strict;
 use warnings;
 
-our $VERSION = '1.20240314';
+our $VERSION = '1.20250610';
 
 use Carp;
 use Data::Dumper;
@@ -11,6 +11,7 @@ use Email::Simple;
 use Encode;
 use IO::Uncompress::Unzip;
 use IO::Uncompress::Gunzip;
+use Module::Load;
 use XML::LibXML;
 
 use parent 'Mail::DMARC::Base';
@@ -20,18 +21,32 @@ require Mail::DMARC::Report::Aggregate::Record;
 
 sub from_imap {
     my $self = shift;
-    eval "require Net::IMAP::Simple";    ## no critic (Eval)
+    load "Net::IMAP::Simple";
     croak "Net::IMAP::Simple seems to not work, is it installed?" if $@;
 
     my $server = $self->config->{imap}{server} or croak "no imap server conf";
     my $folder = $self->config->{imap}{folder} or croak "no imap folder conf";
     my $a_done = $self->config->{imap}{a_done};
     my $f_done = $self->config->{imap}{f_done};
-    my $port   = $self->config->{imap}{port} // $self->get_imap_port();
+    my $port   = $self->config->{imap}{port} // 993;
+
+    if ($port != 143) {
+        eval "use IO::Socket::SSL";  ## no critic (Eval)
+        if ( $@ ) {
+            croak "Can't load IO::Socket::SSL: $!\n";
+        };
+
+        if (defined $self->config->{imap}{SSL_verify_mode}) {
+            IO::Socket::SSL::set_ctx_defaults(
+                SSL_verifycn_scheme => 'imap',
+                SSL_verify_mode => $self->config->{imap}{SSL_verify_mode},
+            );
+        }
+    }
 
     no warnings qw(once);                ## no critic (Warn)
     my $imap = Net::IMAP::Simple->new( $server, port => $port,
-           ($port != 143) ? (use_ssl => 1) : ()
+           use_ssl => $port != 143,
         )
         or do {
             ## no critic (PackageVar)
@@ -98,7 +113,7 @@ sub from_mbox {
 
     # TODO: replace this module
     # commented out due to build test failures
-    #   eval "require Mail::Mbox::MessageParser";    ## no critic (Eval)
+    #   load "Mail::Mbox::MessageParser";
     #   croak "is Mail::Mbox::MessageParser installed?" if $@;
 
     #   my $file_handle = FileHandle->new($file_name);
@@ -183,33 +198,6 @@ sub from_email_simple {
     return $rep_type;
 }
 
-sub get_imap_port {
-    my $self = shift;
-
-    eval "use IO::Socket::SSL";  ## no critic (Eval)
-    if ( $@ ) {
-        carp "no SSL, using insecure connection: $!\n";
-        return 143;
-    };
-
-    eval "use Mozilla::CA";    ## no critic (Eval)
-    if ( ! $@ ) {
-        IO::Socket::SSL::set_ctx_defaults(
-                SSL_verifycn_scheme => 'imap',
-                SSL_verify_mode => 0x02,
-                SSL_ca_file => Mozilla::CA::SSL_ca_file(),
-                );
-        return 993;
-    };
-
-    # no CA, disable verification
-    IO::Socket::SSL::set_ctx_defaults(
-        SSL_verifycn_scheme => 'imap',
-        SSL_verify_mode => 0,
-    );
-    return 993;
-}
-
 sub get_submitter_from_filename {
     my ( $self, $filename ) = @_;
     return if $self->{_envelope_to};  # already parsed from Subject:
@@ -421,7 +409,7 @@ Mail::DMARC::Report::Receive - process incoming DMARC reports
 
 =head1 VERSION
 
-version 1.20240314
+version 1.20250610
 
 =head1 DESCRIPTION
 
@@ -469,7 +457,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2024 by Matt Simerson.
+This software is copyright (c) 2025 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
